==> neuroimage_denoiser_gui-1.3.1.tar.gz: neuroimage_denoiser_gui-1.3.1/readme.md <==
# Neuroimage Denoiser GUI

![Python Version from PEP 621 TOML](https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2Fandreasmz%2Fneuroimage_denoiser_gui%2Fmain%2Fpyproject.toml&style=flat&logo=Python)
![Dynamic TOML Badge](https://img.shields.io/badge/dynamic/toml?url=https%3A%2F%2Fraw.githubusercontent.com%2Fandreasmz%2Fneuroimage_denoiser_gui%2Fmain%2Fpyproject.toml&query=%24.project.version&label=Version&color=09bd2d)
![Dynamic TOML Badge](https://img.shields.io/badge/dynamic/toml?url=https%3A%2F%2Fraw.githubusercontent.com%2Fandreasmz%2Fneuroimage_denoiser_gui%2Fmain%2Fpyproject.toml&query=%24.project.classifiers%5B1%5D&label=PyProject.toml&color=09bd2d)


A simple implementation of a user GUI for [Neuroimage Denoiser](https://github.com/s-weissbach/neuroimage_denoiser) for iternal use in the AG Heine. All credits of the program itself go to Weissbach et al.

## Installation
Create an environment (for example using conda) and type inside of it

```bash
pip install neuroimage-denoiser-gui
```

You can now access it using 
```bash
python -m neuroimage_denoiser_gui
```

## Citation

<span style="color:red;">Please note</span>: For citation refer to the main repository.

**Neuroimage Denoiser for removing noise from transient fluorescent signals in functional imaging.**
Stephan Weissbach, Jonas Milkovits, Michela Borghi, Carolina Amaral, Abderazzaq El Khallouqi, Susanne Gerber, Martin Heine
*bioRxiv* 2024.06.08.598061; doi: https://doi.org/10.1101/2024.06.08.598061

## Gallery

<p align="center">
    <img src="https://raw.githubusercontent.com/andreasmz/neuroimage_denoiser_gui/main/neuroimage_denoiser_screenshot01.png" style="max-width: 600px;">
</p>

==> neuroimage_denoiser_gui-1.4.3.tar.gz: neuroimage_denoiser_gui-1.4.3/readme.md <==
# Neuroimage Denoiser GUI

![Python Version from PEP 621 TOML](https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2Fandreasmz%2Fneuroimage_denoiser_gui%2Fmain%2Fpyproject.toml&style=flat&logo=Python)
![Dynamic TOML Badge](https://img.shields.io/badge/dynamic/toml?url=https%3A%2F%2Fraw.githubusercontent.com%2Fandreasmz%2Fneuroimage_denoiser_gui%2Fmain%2Fpyproject.toml&query=%24.project.version&label=Version&color=09bd2d)
![Dynamic TOML Badge](https://img.shields.io/badge/dynamic/toml?url=https%3A%2F%2Fraw.githubusercontent.com%2Fandreasmz%2Fneuroimage_denoiser_gui%2Fmain%2Fpyproject.toml&query=%24.project.classifiers%5B1%5D&label=PyProject.toml&color=09bd2d)


A simple implementation of a user GUI for [Neuroimage Denoiser](https://github.com/s-weissbach/neuroimage_denoiser) for iternal use in the AG Heine. All credits of the program itself go to Weissbach et al.

## Installation
Create an environment (for example using conda) and type inside of it

```bash
pip install neuroimage_denoiser_gui
```

You can now access it using 
```bash
python -m neuroimage_denoiser_gui
```

## Citation

<span style="color:red;">Please note</span>: For citation refer to the main repository.

**Neuroimage Denoiser for removing noise from transient fluorescent signals in functional imaging.**
Stephan Weissbach, Jonas Milkovits, Michela Borghi, Carolina Amaral, Abderazzaq El Khallouqi, Susanne Gerber, Martin Heine
*bioRxiv* 2024.06.08.598061; doi: https://doi.org/10.1101/2024.06.08.598061

## Gallery

<p align="center">
    <img src="https://raw.githubusercontent.com/andreasmz/neuroimage_denoiser_gui/main/neuroimage_denoiser_screenshot01.png" style="max-width: 600px;">
</p>
